==> haskell-quickcheck-unicode-1.0.1.0-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-unicode
version: 1.0.1.0
id: quickcheck-unicode-1.0.1.0-9CXrHSyFPuC9xe9j2mPdPV
key: quickcheck-unicode-1.0.1.0-9CXrHSyFPuC9xe9j2mPdPV
license: BSD-2-Clause
copyright: 2014-2017 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/quickcheck-unicode
synopsis: Generator and shrink functions for testing
          Unicode-related software.
description:
    Generator and shrink functions for testing
    Unicode-related software.
category: Testing, Text
abi: bc2bb1f1267bb3802eb8544656d7f21e
exposed: True
exposed-modules:
    Test.QuickCheck.Unicode
import-dirs: /usr/lib/ghc-8.6.3/site-local/quickcheck-unicode-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/quickcheck-unicode-1.0.1.0
hs-libraries: HSquickcheck-unicode-1.0.1.0-9CXrHSyFPuC9xe9j2mPdPV
depends:
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-unicode-1.0.1.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-unicode
version: 1.0.1.0
id: quickcheck-unicode-1.0.1.0-1kMhuIE29ZjIlfOq7K36SQ
key: quickcheck-unicode-1.0.1.0-1kMhuIE29ZjIlfOq7K36SQ
license: BSD-2-Clause
copyright: 2014-2017 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/quickcheck-unicode
synopsis: Generator and shrink functions for testing
          Unicode-related software.
description:
    Generator and shrink functions for testing
    Unicode-related software.
category: Testing, Text
abi: 6f157f15712d8942626065ba7f048daa
exposed: True
exposed-modules:
    Test.QuickCheck.Unicode
import-dirs: /usr/lib/ghc-8.6.3/site-local/quickcheck-unicode-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/quickcheck-unicode-1.0.1.0
hs-libraries: HSquickcheck-unicode-1.0.1.0-1kMhuIE29ZjIlfOq7K36SQ
depends:
    QuickCheck-2.12.6.1-4a6Ozz7bfHzLQyA4XOD1Dc base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
